| get_registered_models_dia | R Documentation |
Retrieves a list of all diagnostic model functions currently registered in the internal environment.
get_registered_models_dia()
A named list where names are the registered model names and values are the corresponding model functions.
register_model_dia, initialize_modeling_system_dia
# Ensure system is initialized to see the default models
initialize_modeling_system_dia()
models <- get_registered_models_dia()
# See available model names
print(names(models))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.