| min_max_normalize | R Documentation |
Performs linear transformation of data to the range 0 to 1. Essential for stacking ensembles to normalize risk scores from heterogeneous base learners.
min_max_normalize(x, min_val = NULL, max_val = NULL)
x |
A numeric vector. |
min_val |
Optional reference minimum value (e.g., from training set). |
max_val |
Optional reference maximum value (e.g., from training set). |
A numeric vector of normalized values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.