| rsf_pro | R Documentation |
Fits a Random Survival Forest using the log-rank splitting rule.
Includes capabilities for hyperparameter tuning via grid search over ntree,
nodesize, and mtry.
rsf_pro(X, y_surv, tune = FALSE, tune_params = NULL)
X |
A data frame of predictors. |
y_surv |
A |
tune |
Logical. If TRUE, performs grid search for optimal hyperparameters based on C-index. |
tune_params |
Optional data frame containing the grid for tuning. |
An object of class survival_rsf and pro_model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.